@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 clients = [{
     'name': _('calibre'),
@@ -16,3 +16,5 @@ backup = {
     },
     'services': ['calibre-server-freedombox']
 }
+
+tags = [_('Ebook'), _('Library'), _('Ebook reader')]
