@@ -3,6 +3,7 @@
 
 import logging
 import pathlib
+from typing import Iterator
 
 from django.urls import reverse_lazy
 from django.utils.translation import gettext_lazy as _
@@ -120,7 +121,7 @@ class CoturnApp(app_module.App):
         privileged.uninstall()
 
 
-def get_available_domains():
+def get_available_domains() -> Iterator[str]:
     """Return an iterator with all domains able to have a certificate."""
     return (domain.name for domain in names.components.DomainName.list()
             if domain.domain_type.can_have_certificate)
