@@ -54,15 +54,15 @@ class MediaWikiApp(app_module.App):
                                clients=manifest.clients, tags=manifest.tags)
         self.add(info)
 
-        menu_item = menu.Menu('menu-mediawiki', info.name,
-                              info.short_description, info.icon_filename,
-                              'mediawiki:index', parent_url_name='apps')
+        menu_item = menu.Menu('menu-mediawiki', info.name, info.icon_filename,
+                              info.tags, 'mediawiki:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = Shortcut('shortcut-mediawiki', info.name,
-                            short_description=info.short_description,
                             icon=info.icon_filename, url='/mediawiki',
-                            clients=info.clients, login_required=True)
+                            clients=info.clients, tags=info.tags,
+                            login_required=True)
         self.add(shortcut)
 
         packages = Packages('packages-mediawiki',
