@@ -70,7 +70,8 @@ class PagekiteApp(app_module.App):
         self.add(packages)
 
         domain_type = DomainType('domain-type-pagekite', _('PageKite Domain'),
-                                 'pagekite:index', can_have_certificate=True)
+                                 configuration_url='pagekite:index',
+                                 can_have_certificate=True, priority=40)
         self.add(domain_type)
 
         daemon = Daemon('daemon-pagekite', self.DAEMON)
