@@ -48,7 +48,11 @@ clients = [{
 
 backup = {
     'secrets': {
-        'directories': ['/var/lib/syncthing/.config']
+        'directories': [
+            '/var/lib/syncthing/.config', '/var/lib/syncthing/.local'
+        ]
     },
     'services': ['syncthing@syncthing']
 }
+
+tags = [_('File sync'), _('File sharing'), _('P2P')]
