@@ -24,18 +24,12 @@ TORPROXY_CONFIG_AUG = f'/files/{TORPROXY_CONFIG}'
 
 
 @privileged
-def setup(old_version: int):
-    """Setup Tor configuration after installing it."""
-    _first_time_setup()
-
-
-def _first_time_setup():
-    """Setup Tor configuration for the first time setting defaults."""
-    logger.info('Performing first time setup for Tor Proxy')
-    # Disable default tor service. We will use tor@fbxproxy instance
-    # instead.
-    _disable_apt_transport_tor()
+def setup():
+    """Setup Tor configuration."""
+    # Disable default Tor service.
     action_utils.service_disable('tor@default')
+    # Mask the service to prevent re-enabling it by the Tor master service.
+    action_utils.service_mask('tor@default')
 
     subprocess.run(['tor-instance-create', INSTANCE_NAME], check=True)
 
@@ -61,8 +55,8 @@ def _first_time_setup():
 
     aug.save()
 
-    action_utils.service_enable(SERVICE_NAME)
-    action_utils.service_restart(SERVICE_NAME)
+    if action_utils.service_is_running(SERVICE_NAME):
+        action_utils.service_restart(SERVICE_NAME)
 
 
 @privileged
@@ -114,17 +108,6 @@ def _get_upstream_bridges(aug) -> str:
     return '\n'.join(bridges)
 
 
-def _enable():
-    """Enable and start the service."""
-    action_utils.service_enable(SERVICE_NAME)
-
-
-def _disable():
-    """Disable and stop the service."""
-    _disable_apt_transport_tor()
-    action_utils.service_disable(SERVICE_NAME)
-
-
 def _use_upstream_bridges(use_upstream_bridges: bool | None = None, aug=None):
     """Enable use of upstream bridges."""
     if use_upstream_bridges is None:
@@ -214,3 +197,4 @@ def uninstall():
         shutil.rmtree(directory, ignore_errors=True)
 
     os.unlink(f'/var/run/tor-instances/{INSTANCE_NAME}.defaults')
+    action_utils.service_unmask(SERVICE_NAME)
