@@ -15,10 +15,7 @@ urlpatterns = [
     re_path(r'^sys/upgrades/firstboot/backports/$',
             views.BackportsFirstbootView.as_view(),
             name='backports-firstboot'),
-    re_path(r'^sys/upgrades/firstboot/update/$',
-            views.UpdateFirstbootView.as_view(), name='update-firstboot'),
-    re_path(r'^sys/upgrades/firstboot/update/progress/$',
-            views.UpdateFirstbootProgressView.as_view(),
-            name='update-firstboot-progress'),
     re_path(r'^sys/upgrades/upgrade/$', views.upgrade, name='upgrade'),
+    re_path(r'^sys/upgrades/test-dist-upgrade/$', views.test_dist_upgrade,
+            name='test-dist-upgrade'),
 ]
