@@ -9,7 +9,6 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import redirect
 from django.urls import reverse_lazy
 from django.utils.translation import gettext as _
-from django.views.generic import TemplateView
 from django.views.generic.edit import FormView
 
 from plinth import __version__
@@ -18,7 +17,7 @@ from plinth.privileged import packages as packages_privileged
 from plinth.views import AppView, messages_error
 
 from . import privileged
-from .forms import BackportsFirstbootForm, ConfigureForm, UpdateFirstbootForm
+from .forms import BackportsFirstbootForm, ConfigureForm
 
 
 class UpgradesConfigurationView(AppView):
@@ -170,47 +169,6 @@ class BackportsFirstbootView(FormView):
         return super().form_valid(form)
 
 
-class UpdateFirstbootView(FormView):
-    """View to run initial update during first boot wizard."""
-
-    template_name = 'update-firstboot.html'
-    form_class = UpdateFirstbootForm
-
-    def __init__(self):
-        """Define instance attribute."""
-        self.update = True
-
-    def get_success_url(self):
-        """Return next firstboot step."""
-        if self.update:
-            return reverse_lazy('upgrades:update-firstboot-progress')
-
-        return reverse_lazy(first_boot.next_step())
-
-    def form_valid(self, form):
-        """Run update if selected, and mark step as done."""
-        self.update = form.cleaned_data['update_now']
-        if self.update:
-            privileged.run()
-
-        first_boot.mark_step_done('initial_update')
-        return super().form_valid(form)
-
-
-class UpdateFirstbootProgressView(TemplateView):
-    """View to show initial update progress."""
-
-    template_name = 'update-firstboot-progress.html'
-
-    def get_context_data(self, *args, **kwargs):
-        context = super().get_context_data(*args, **kwargs)
-        context['is_busy'] = (_is_updating()
-                              or packages_privileged.is_package_manager_busy())
-        context['next_step'] = first_boot.next_step()
-        context['refresh_page_sec'] = 3 if context['is_busy'] else None
-        return context
-
-
 def test_dist_upgrade(request):
     """Test dist-upgrade from stable to testing."""
     if request.method == 'POST':
