@@ -22,6 +22,17 @@
   for the JavaScript code in this page.
 */
 
+/*
+ * Remove the 'no-js' class from the <body> element. CSS utilizing this can
+ * create different rules when Javascript is available and when it is not. This
+ * functionality was provided by the Modernizr library earlier.
+ */
+document.addEventListener('DOMContentLoaded', function(event) {
+    const html = document.querySelector('html');
+    html.classList.remove('no-js');
+    html.classList.add('js');
+});
+
 /*
  * Refresh page if marked for refresh.
  */
@@ -126,9 +137,14 @@ window.addEventListener('pageshow', function(event) {
  * Select all option for multiple checkboxes.
  */
 document.addEventListener('DOMContentLoaded', function(event) {
-    let parents = document.querySelectorAll('ul.has-select-all');
+    // Django < 4.0 generates <ul> and <li> where as Django >= 4.0 generates <div>s
+    let parents = document.querySelectorAll('ul.has-select-all,div.has-select-all');
     for (const parent of parents) {
-        let li = document.createElement('li');
+        let childElementType = 'div';
+        if (parent.tagName.toLowerCase() == 'ul')
+            childElementType = 'li';
+
+        let selectAllItem = document.createElement(childElementType);
 
         let label = document.createElement('label');
         label.for = "select_all";
@@ -139,9 +155,9 @@ document.addEventListener('DOMContentLoaded', function(event) {
         checkbox.setAttribute('class', 'select-all');
 
         label.appendChild(checkbox);
-        li.appendChild(label);
+        selectAllItem.appendChild(label);
 
-        parent.insertBefore(li, parent.childNodes[0]);
+        parent.insertBefore(selectAllItem, parent.childNodes[0]);
         setSelectAllValue(parent);
 
         checkbox.addEventListener('change', onSelectAllChanged);
